@@ -8,7 +8,9 @@ with open("README_Log.md", "r") as fh:
 
 setuptools.setup(
     name="pcs_log",
-    version="0.3.7",
+    version="0.3.8",
+    metadata_version="2.3",
+    python_requires='>=3.6',
     author="Rainer Pietsch",
     author_email="r.pietsch@pcs-at.com",
     description="Generic logger",
